com.eldrix.dmd.core


amps-for-productclj

(amps-for-product conn id)
source

atc->products-for-eclclj

(atc->products-for-ecl conn atc)

Return a map of products that can be used to build a more complete SNOMED CT ECL expression that will include all matching UK products. We have to do it this way because TF products are not included in the UK dm+d distribution.

Return a map of products that can be used to build a more complete SNOMED CT
ECL expression that will include all matching UK products. We have to do it
this way because TF products are not included in the UK dm+d distribution.
sourceraw docstring

atc->snomed-eclcljdeprecated

(atc->snomed-ecl conn atc)

Create a SNOMED CT ECL expression from the ATC pattern specified, returning an expression that will return VTMs, VMPs and AMPs. Prefer to use atc->products-for-ecl and the SNOMED CT drug extension to optimise the creation of the appropriate ECL expression.

Create a SNOMED CT ECL expression from the ATC pattern specified, returning
an expression that will return VTMs, VMPs and AMPs.
Prefer to use [[atc->products-for-ecl]] and the SNOMED CT drug extension
to optimise the creation of the appropriate ECL expression.
sourceraw docstring

atc-for-productclj

(atc-for-product conn id)
source

closeclj

(close st)
source

current-idsclj

(current-ids conn id)

Returns the set of identifiers in current use for the given (usually historic) identifier.

Returns the set of identifiers in current use for the given (usually
historic) identifier.
sourceraw docstring

dmd-database?clj

(dmd-database? f)

Returns true if f is a dm+d SQLite database created by this library. Strict: legacy dm+d files predating the application_id marker return false.

Returns true if `f` is a dm+d SQLite database created by this library.
Strict: legacy dm+d files predating the application_id marker return false.
sourceraw docstring

fetch-historyclj

(fetch-history conn id)

Returns all history entries in which id is the current identifier, ordered by start date, including 'self' entries recording the period of validity of the current identifier itself.

Returns all history entries in which `id` is the current identifier,
ordered by start date, including 'self' entries recording the period of
validity of the current identifier itself.
sourceraw docstring

fetch-lookupclj

(fetch-lookup conn lookup-kind)
source

fetch-productclj

(fetch-product store product-id)
source

fetch-product-by-exact-nameclj

(fetch-product-by-exact-name conn nm)
source

fetch-release-dateclj

(fetch-release-date store)
source

install-from-dirsclj

(install-from-dirs filename dirs & {:keys [_batch-size] :as opts})

Creates a new dm+d filestore at filename from the directories specified.

Creates a new dm+d filestore at `filename` from the directories specified.
sourceraw docstring

install-latestclj

(install-latest api-key-file cache-dir)

Convenience function to install latest release using a filename based on its release date. For more control, use install-release.

Convenience function to install latest release using a filename based on its release date. 
For more control, use `install-release`.
sourceraw docstring

install-releaseclj

(install-release api-key-file cache-dir)
(install-release api-key-file cache-dir filename)
(install-release api-key-file cache-dir filename release-date)

Create a versioned dm+d file-based database by downloading the dm+d distributions automatically from NHS Digital's TRUD service. Parameters:

  • api-key-file : file containing TRUD API key, anything coercible using [[clojure.java.io/as-file]]
  • cache-dir : TRUD cache directory
  • filename : filename of database to install, can be omitted
  • release-date : date of release to be installed, will use latest if omitted. can be a string in ISO format, or a java.time.LocalDate
Create a versioned dm+d file-based database by downloading the dm+d
distributions automatically from NHS Digital's TRUD service.
Parameters:
- api-key-file : file containing TRUD API key, anything coercible using 
                 [[clojure.java.io/as-file]]
- cache-dir    : TRUD cache directory
- filename     : filename of database to install, can be omitted
- release-date : date of release to be installed, will use latest if omitted.
                 can be a string in ISO format, or a java.time.LocalDate
sourceraw docstring

lookup-typesclj

Set of lookup types, as keywords, usable with fetch-lookup.

Set of lookup types, as keywords, usable with [[fetch-lookup]].
sourceraw docstring

open-storeclj

(open-store f)

Open a dm+d store. Returns what should be regarded as an opaque handle, that should be closed using close. Currently this is a DataSource but this is subject to change. f can be anything coercible to a file using [[clojure.java.io/as-file]]. Throws an exception if the file does not exist.

Open a dm+d store. Returns what should be regarded as an opaque handle,
that should be closed using `close`. Currently this is a DataSource but
this is subject to change. `f` can be anything coercible to a file using
[[clojure.java.io/as-file]]. Throws an exception if the file does not exist.
sourceraw docstring

plan-productsclj

(plan-products conn product-type)

Returns a reducible over all rows of the given product type (:VTM :VMP :AMP :VMPP or :AMPP), for streaming iteration; each row is a next.jdbc row abstraction with columns accessible by keyword.

Returns a reducible over all rows of the given product type (:VTM :VMP
:AMP :VMPP or :AMPP), for streaming iteration; each row is a `next.jdbc`
row abstraction with columns accessible by keyword.
sourceraw docstring

previous-idsclj

(previous-ids conn id)

Returns the set of prior identifiers for the given current identifier.

Returns the set of prior identifiers for the given current identifier.
sourceraw docstring

(print-available-releases api-key)
source

products-from-atccljdeprecated

(products-from-atc conn atc)
(products-from-atc conn atc product-types)

Returns a sequence of products matching the ATC code. Parameters:

  • conn :
  • atc : atc code - supports '*' and '?' for pattern matching as per Lucene
  • product-types : a set of product types (e.g. #{:VTM :VMP :AMP :VMPP :AMPP}).

By default only VTM VMP and AMP products will be returned.

Returns a sequence of products matching the ATC code.
Parameters:
- conn          :
- atc           : atc code - supports '*' and '?' for pattern matching as per Lucene
- product-types : a set of product types (e.g. #{:VTM :VMP :AMP :VMPP :AMPP}).

By default only VTM VMP and AMP products will be returned.
sourceraw docstring

(search conn s & {:keys [_types _limit] :as opts})

Search product names, returning a sequence of maps of :SEARCH/ID, :SEARCH/TYPE and :SEARCH/NM, best matches first. Each token is matched as a prefix; multiple tokens must all match. Options:

  • :types - product types to include e.g. #{:VMP :AMP}; default, all
  • :limit - maximum number of results; default 100
Search product names, returning a sequence of maps of :SEARCH/ID,
:SEARCH/TYPE and :SEARCH/NM, best matches first. Each token is matched as
a prefix; multiple tokens must all match.
Options:
- :types - product types to include e.g. #{:VMP :AMP}; default, all
- :limit - maximum number of results; default 100
sourceraw docstring

sqlite-database?clj

(sqlite-database? f)

Returns true if f is a SQLite 3 database file.

Returns true if `f` is a SQLite 3 database file.
sourceraw docstring

statusclj

(status store)

Returns a structured description of an open dm+d store, including store schema version, creation date, dm+d release date, source TRUD release information and file inventory when available, and entity counts.

Returns a structured description of an open dm+d store, including store
schema version, creation date, dm+d release date, source TRUD release
information and file inventory when available, and entity counts.
sourceraw docstring

vmps-for-productclj

(vmps-for-product conn id)
source

vmps-from-atccljdeprecated

(vmps-from-atc conn atc)

DEPRECATED: use vpids-from-atc instead.

DEPRECATED: use [[vpids-from-atc]] instead.
sourceraw docstring

vpids-from-atcclj

(vpids-from-atc conn atc)

Returns a sequence of VPIDs for the ATC code specified.

  • conn
  • atc - atc code - supports '*' for multiple character wildcard, and '?' for single character wildcard.
Returns a sequence of VPIDs for the ATC code specified. 
- conn
- atc - atc code - supports '*' for multiple character wildcard, and '?' for single character wildcard.
sourceraw docstring

vtm-ingredientsclj

(vtm-ingredients conn vtmid)

Returns ingredient (ISID) identifiers for the given VTM.

Returns ingredient (ISID) identifiers for the given VTM.
sourceraw docstring

vtms-for-ingredientclj

(vtms-for-ingredient conn isid)

Returns VTM identifiers for the given ingredient.

Returns VTM identifiers for the given ingredient.
sourceraw docstring

vtms-for-productclj

(vtms-for-product conn id)
source

cljdoc builds & hosts documentation for Clojure/Script libraries